# API Reference

::: thecodecrate_pipeline.core
    options:
        show_if_no_docstring: true
        preload_modules:
            - "_api"
            - "thecodecrate_pipeline"
        members:
            - T_in
            - T_out
            - Pipeline
            - PipelineFactory
            - Stage
            - Processor
